//******************************************************************************
//   MSP430G2xx3 Demo - USCI_A0, 115200 UART Echo ISR, DCO SMCLK
//
//   Description: Echo a received character, RX ISR used. Normal mode is LPM0.
//   USCI_A0 RX interrupt triggers TX Echo.
//   Baud rate divider with 1MHz = 1MHz/115200 = ~8.7
//   ACLK = n/a, MCLK = SMCLK = CALxxx_1MHZ = 1MHz
//
//                MSP430G2xx3
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//  <---EN----|P1.0(LED)        |
//            |     P1.2/UCA0TXD|------------>
//  -----AD-->|P1.5(A5)         | 9600 - 8N1
//            |     P1.1/UCA0RXD|<------------
//	PWM1<-----|P2.1      P2.3/IO|<----low-to-high interrupt
//	PWM2<-----|P2.5      P2.4/IO|<--DS18B20-->
//            |       P1.6/TA0.1|<-Capture----
//   D. Dang
//   Texas Instruments Inc.
//   February 2011
//   Built with CCS Version 4.2.0 and IAR Embedded Workbench Version: 5.10
//******************************************************************************
#include "msp430g2433.h"
#include "Define.h"
#include "DS18b20.h"
#include "Globals.h"

unsigned int wendu=0;
unsigned int j = 1;
unsigned char flag=0;

unsigned int ADC10_Results = 0;

void uart_init(void);
void ADC_init(void);
void timer_a_PWM(void);
void timer_1s(void);
void uart_transmit(uchar temp);
void Port2_int(void);
uint AD_GetValue(void);
void Delay_10us(unsigned int i)
{
	while(i--);
}
void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT
  BCSCTL1 = CALBC1_8MHZ;                    // Set DCO
  DCOCTL = CALDCO_8MHZ;						//Ϊ8MHZ

  P1DIR |= 0x41;                        		// P1.0 P1.6 output (green LED)
  P1OUT  = 0x00;

  P2DIR &=~BIT0;			//Ϊ

  uart_init();
  ADC_init();
  Port2_int();				//port2ж

  // timer_1s();				//ʱж
  //timer_a_PWM();
  IE2 |= UCA0RXIE;                           // Enable USCI_A0 RX interrupt
  __bis_SR_register(GIE);					 //Enable interrupt
  while(1)
  {
	//  uart_transmit(0x08);
	  j=Init_18B20();
	  wendu = Do1Convert();
	  Recieve[1]=wendu>>8;		//¶ȸλ
	  Recieve[2]=wendu;			//¶ȵλ
	  if(P2IN&BIT0)				//
	  {
		  P1OUT |=BIT6;			//⵽˸ֵΪ1
		  Recieve[3]=1;
		  flag=1;
	  }else
	  {
		  P1OUT &= ~BIT6;
		  Recieve[3]=0;			//⵽û˸ֵΪ0
		  flag=0;
	  }
	  ADC10_Results = AD_GetValue();
	  Recieve[4]=ADC10_Results>>8;	//ʪȸλ
	  Recieve[5]=ADC10_Results;		//ʪȵλ
	  _NOP();

  }// TX -> RXed character
}// Enter LPM0, interrupts enabled

void timer_a_PWM(void)
{
	  P2DIR |= 0x22;                            // P2.1 and P2.5 output
	  P2SEL |= 0x22;                            // P2.1 and P2.5 TA1/2 options
	  TA1CCR0 = 200-1;                          // PWM Period
	  TA1CCTL1 = OUTMOD_7;                      // TA1CCR1 reset/set
	  TA1CCTL2 = OUTMOD_7;						// TA1CCR2 reset/set
	  TA1CCR1 = 20;                             // TA1CCR1 PWM duty cycle
	  TA1CCR2 = 20;
	  TA1CTL = TASSEL_2 | MC_1 | ID_3;          // SMCLK, up mode
}
void timer_1s(void)
{
	 CCTL0 = CCIE;                             // CCR0 interrupt enabled
	 CCR0 = 50000;
	 TACTL = TASSEL_2 + MC_2 + ID_3;                  // SMCLK, contmod
	 _BIS_SR(GIE);                 //interrupt
}
void uart_init(void)
{
	  P1SEL = BIT1 + BIT2 ;                      // P1.1 = RXD, P1.2=TXD
	  P1SEL2 = BIT1 + BIT2;
	  UCA0CTL1 |= UCSSEL_2 ;                     // SMCLK
	  UCA0BR0 = 0x41;                            // 8MHz 9600
	  UCA0BR1 = 0x03;                            // 8MHz 9600
	  UCA0MCTL =  UCBRS0 | UCBRS1;               // Modulation UCBRSx = 3
	  UCA0CTL1 &= ~UCSWRST;
}
void uart_transmit(uchar temp)
{
	 while (!(IFG2&UCA0TXIFG));                // USCI_A0 TX buffer ready?
	 UCA0TXBUF = temp;
}
void ADC_init(void)
{
	  ADC10CTL0 = SREF_0 + ADC10SHT_2 + ADC10ON; // + ADC10IE; // ADC10ON, interrupt enabled
	  ADC10CTL1 = INCH_5 + SHS_0;                // input A5,P1.5 Sample-and-hold source select --ADC10SC
	  ADC10AE0 |= 0x20;                          // PA.5 ADC option select
	  ADC10CTL0 |= ENC + ADC10SC;                // Sampling and conversion start
}
uint AD_GetValue(void)
{
	uint AD_vale=0;
	while(!(ADC10CTL0&ADC10IFG));
	AD_vale = ADC10MEM & 0x03ff;
	return AD_vale;
}
void Port2_int(void)
{
	P2IE |= BIT3;		//The interrupt is enabled
	P2IES &= ~BIT3;		//low-to-high transition
	P2IFG &= ~BIT3;		//clear interrupt flag
}
#pragma vector=PORT2_VECTOR
__interrupt void PORT2_ISR(void)		//ж
{
	if(P2IFG&BIT3)
	{
		  P1OUT ^= BIT0;
		  Recieve[6] = 1;				//紫⵽˸ߵƽ
		  P2IFG &= ~BIT3;
	}
}
#pragma vector=USCIAB0RX_VECTOR
__interrupt void USCI0RX_ISR(void)
{

	Recieve[0]= UCA0RXBUF;        //ݼĴ
	if(Recieve[0]==0xFF)		  //ַΪFF
	{
		for(Recieve_count=1;Recieve_count<=6;Recieve_count++)
		{
			uart_transmit(Recieve[Recieve_count]);	//յַ뷢
		}
		uart_transmit(0x02);
		uart_transmit(0xFF);		//Ӧ룬߷
	}
	IFG2 &= ~UCA0RXIFG;					//жϱ־λ
}
/*#pragma vector=TIMER0_A0_VECTOR
__interrupt void Timer_A(void)
{
	 PIT_n++;
	 if(PIT_n>7)
	  {
	   PIT_n=0;
	  }
	  PIT_Time1++;

	  if(PIT_Time1>10)
	  {
		uart_transmit(wendu);
		PIT_Time1=0;
	  }
	CCR0 += 50000;                            // Add Offset to CCR0
}*/
// Echo back RXed character, confirm TX buffer is ready first
